@@ -224,19 +224,31 @@ void create_main_window()
     btConjg = gtk_button_new_with_mnemonic(_("conjugate"));
     gtk_widget_show(btConjg);
     gtk_box_pack_start(GTK_BOX(hbox1), btConjg, FALSE, FALSE, 0);
+#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
     gtk_button_set_focus_on_click(GTK_BUTTON(btConjg), FALSE);
+#else
+    gtk_widget_set_focus_on_click(btConjg, FALSE);
+#endif
 
     btFont = gtk_button_new_with_label("Aa");
     gtk_widget_set_tooltip_text (btFont, _("Set font"));
     gtk_widget_show(btFont);
     gtk_box_pack_end(GTK_BOX(hbox1), btFont, FALSE, FALSE, 0);
+#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
     gtk_button_set_focus_on_click(GTK_BUTTON(btFont), FALSE);
+#else
+    gtk_widget_set_focus_on_click(btFont, FALSE);
+#endif
 
     btCommon = gtk_check_button_new_with_label("Br");
     gtk_widget_set_tooltip_text (btCommon, _("Conjugate verbs as ordinary Brazilians do"));
     gtk_widget_show(btCommon);
     gtk_box_pack_end(GTK_BOX(hbox1), btCommon, FALSE, FALSE, 0);
+#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
     gtk_button_set_focus_on_click(GTK_BUTTON(btCommon), FALSE);
+#else
+    gtk_widget_set_focus_on_click(btCommon, FALSE);
+#endif
 
     scrolledwindow1 = gtk_scrolled_window_new(NULL, NULL);
     gtk_widget_show(scrolledwindow1);
@@ -306,11 +318,17 @@ void create_main_window()
             for(i = 0; i < strlen(FontDesc); i++)
                 if(FontDesc[i] == '\n' || FontDesc[i] == '\r')
                     FontDesc[i] = 0;
-            PangoFontDescription *font_desc = pango_font_description_from_string(FontDesc);
-            // FIXME: The code below uses a deprecated function (GDK_DEPRECATED_IN_3_16)
-            // gedit still uses this function too (gedit-view.c, around line 1000).
-            gtk_widget_override_font(textview1, font_desc);
-            pango_font_description_free(font_desc);
+            char fdcss[512];
+            snprintf(fdcss, 511, "GtkTextView { font: %s; }", FontDesc);
+
+            GtkCssProvider *provider = gtk_css_provider_new();
+            GdkDisplay *display = gdk_display_get_default();
+            GdkScreen *screen = gdk_display_get_default_screen(display);
+            gtk_style_context_add_provider_for_screen(screen,
+                    GTK_STYLE_PROVIDER(provider),
+                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+            gtk_css_provider_load_from_data(provider, fdcss, -1, NULL);
+            g_object_unref(provider);
         }
         fclose(F);
     }
